@@ -89,7 +89,7 @@ class HtmlFrame(ttk.Frame):
         self.html.done_loading_func = self.done_loading
 
         self.message_func(
-            "Welcome to TkinterWeb 3.9! \nhttps://github.com/Andereoo/TkinterWeb")
+            "Welcome to TkinterWeb 3.10! \nhttps://github.com/Andereoo/TkinterWeb")
 
         self.message_func(
             "Debugging messages are enabled. \nUse the parameter `messages_enabled = False` when calling HtmlFrame() to disable these messages.")
@@ -148,7 +148,7 @@ class HtmlFrame(ttk.Frame):
             if method == "GET":
                 url = str(url) + str(data)
             # if url is different than the current one, load the new site.
-            if force or (method == "POST") or (urldefrag(url).url != urldefrag(self.current_url).url):
+            if force or (method == "POST") or (urldefrag(url)[0] != urldefrag(self.current_url)[0]):
                 self.message_func("Connecting to {0}.".format(parsed.netloc))
                 if (parsed.scheme == "file") or (not self.html.caches_enabled):
                     data, newurl, filetype = download(
@@ -304,6 +304,10 @@ class HtmlFrame(ttk.Frame):
         "Disabling this will remove all emojis, the noto color emoji font, and invalid rgb functions"
         self.html.prevent_crashes = isenabled
 
+    def find_text(self, searchtext, select=1, ignore_case=True, highlight_all=True):
+        "Search for and highlight specific text"
+        return self.html.find_text(searchtext, select, ignore_case, highlight_all)
+
     def change_cursor(self, cursor):
         "Handle cursor changes"
         if self.cursor != cursor:
